@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.tpu import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from .services.tpu import TpuAsyncClient, TpuClient
 from .types.cloud_tpu import (
@@ -20,13 +24,16 @@ from .types.cloud_tpu import (
     AccessConfig,
     AttachedDisk,
     CreateNodeRequest,
+    CreateQueuedResourceRequest,
     DeleteNodeRequest,
+    DeleteQueuedResourceRequest,
     GenerateServiceIdentityRequest,
     GenerateServiceIdentityResponse,
     GetAcceleratorTypeRequest,
     GetGuestAttributesRequest,
     GetGuestAttributesResponse,
     GetNodeRequest,
+    GetQueuedResourceRequest,
     GetRuntimeVersionRequest,
     GuestAttributes,
     GuestAttributesEntry,
@@ -35,17 +42,22 @@ from .types.cloud_tpu import (
     ListAcceleratorTypesResponse,
     ListNodesRequest,
     ListNodesResponse,
+    ListQueuedResourcesRequest,
+    ListQueuedResourcesResponse,
     ListRuntimeVersionsRequest,
     ListRuntimeVersionsResponse,
     NetworkConfig,
     NetworkEndpoint,
     Node,
     OperationMetadata,
+    QueuedResource,
+    QueuedResourceState,
     RuntimeVersion,
     SchedulingConfig,
     ServiceAccount,
     ServiceIdentity,
     ShieldedInstanceConfig,
+    SimulateMaintenanceEventRequest,
     StartNodeRequest,
     StopNodeRequest,
     Symptom,
@@ -58,13 +70,16 @@ __all__ = (
     "AccessConfig",
     "AttachedDisk",
     "CreateNodeRequest",
+    "CreateQueuedResourceRequest",
     "DeleteNodeRequest",
+    "DeleteQueuedResourceRequest",
     "GenerateServiceIdentityRequest",
     "GenerateServiceIdentityResponse",
     "GetAcceleratorTypeRequest",
     "GetGuestAttributesRequest",
     "GetGuestAttributesResponse",
     "GetNodeRequest",
+    "GetQueuedResourceRequest",
     "GetRuntimeVersionRequest",
     "GuestAttributes",
     "GuestAttributesEntry",
@@ -73,17 +88,22 @@ __all__ = (
     "ListAcceleratorTypesResponse",
     "ListNodesRequest",
     "ListNodesResponse",
+    "ListQueuedResourcesRequest",
+    "ListQueuedResourcesResponse",
     "ListRuntimeVersionsRequest",
     "ListRuntimeVersionsResponse",
     "NetworkConfig",
     "NetworkEndpoint",
     "Node",
     "OperationMetadata",
+    "QueuedResource",
+    "QueuedResourceState",
     "RuntimeVersion",
     "SchedulingConfig",
     "ServiceAccount",
     "ServiceIdentity",
     "ShieldedInstanceConfig",
+    "SimulateMaintenanceEventRequest",
     "StartNodeRequest",
     "StopNodeRequest",
     "Symptom",
